@@ -4,7 +4,7 @@ Configuration schema for Astoria.
 Common to all components.
 """
 from pathlib import Path
-from typing import IO, List, Optional
+from typing import IO, Dict, List, Optional
 
 from pydantic import BaseModel
 from toml import load
@@ -50,12 +50,20 @@ class SystemInfo(BaseModel):
         extra = "forbid"
 
 
+class ProcessManagerInfo(BaseModel):
+    """Settings specifically for astprocd."""
+
+    default_usercode_entrypoint: str = "robot.py"
+
+
 class AstoriaConfig(BaseModel):
     """Config schema for Astoria."""
 
     mqtt: MQTTBrokerInfo
     wifi: WiFiInfo
+    astprocd: ProcessManagerInfo = ProcessManagerInfo()  # Optional section
     system: SystemInfo
+    env: Dict[str, str] = {}
 
     class Config:
         """Pydantic config."""
